# ActivitiesSummaryV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30**](LastModifiedDateV30.md) |  | [optional] 
**distinctions** | [**DistinctionsSummaryV30**](DistinctionsSummaryV30.md) |  | [optional] 
**educations** | [**EducationsSummaryV30**](EducationsSummaryV30.md) |  | [optional] 
**employments** | [**EmploymentsSummaryV30**](EmploymentsSummaryV30.md) |  | [optional] 
**fundings** | [**FundingsV30**](FundingsV30.md) |  | [optional] 
**invited_positions** | [**InvitedPositionsV30**](InvitedPositionsV30.md) |  | [optional] 
**memberships** | [**MembershipsV30**](MembershipsV30.md) |  | [optional] 
**peer_reviews** | [**PeerReviewsV30**](PeerReviewsV30.md) |  | [optional] 
**qualifications** | [**QualificationsV30**](QualificationsV30.md) |  | [optional] 
**research_resources** | [**ResearchResourcesV30**](ResearchResourcesV30.md) |  | [optional] 
**services** | [**ServicesV30**](ServicesV30.md) |  | [optional] 
**works** | [**WorksSummaryV30**](WorksSummaryV30.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

